@@ -1,5 +1,8 @@
 #!/usr/bin/env python
 
+# Version: 2.0
+# Date: 17 Dec 2013
+
 
 # Copyright 2013 Max Black
 
@@ -17,21 +20,44 @@
 # along with this program.  If not, see http://www.gnu.org/licenses/.
 
 
-class Colours(object):
+
+class Fore(object):
     """contains ansi escape characters which change the text colour
     of a terminal application"""
     
-    TURQUOISE = "\033[96m"
-    PURPLE = "\033[95m"
-    BLUE = "\033[94m"
-    GREEN = "\033[92m"
-    YELLOW = "\033[93m"
-    RED = "\033[91m"
-    GRAY = "\033[90m"
-    RESET = "\033[0m"
+    BLACK = "\033[30m"
+    RED = "\033[31m"
+    GREEN = "\033[32m"
+    YELLOW = "\033[33m"
+    BLUE = "\033[34m"
+    MAGENTA = "\033[35m"
+    CYAN = "\033[36m"
+    WHITE = "\033[37m"
+    
+class Back(object):
+    """contains ansi escape characters which change the text colour
+    of a terminal application"""
+    
+    BLACK = "\033[40m"
+    RED = "\033[41m"
+    GREEN = "\033[42m"
+    YELLOW = "\033[43m"
+    BLUE = "\033[44m"
+    MAGENTA = "\033[45m"
+    CYAN = "\033[46m"
+    WHITE = "\033[47m"
+
+class Formatting(object):
+    """Contains ansi escape characters which change the formating (bold,
+    underscore, etc) of text in a terminal application"""
+    
+    BOLD = "\033[1m"
+    UNDERSCORE = "\033[4m"
+    
+    RESET_ALL = "\033[0m"
 
 
-def rainbow(msg, colours=["\033[96m","\033[95m","\033[94m","\033[93m","\033[92m","\033[91m","\033[90m", "\033[0m"], end="\033[0m\n"):
+def rainbow(msg, colours=["\033[30m", "\033[31m", "\033[32m", "\033[33m", "\033[34m", "\033[35m", "\033[36m", "\033[37m", "\033[0m"], end="\033[0m\n"):
     """print text with each letter a different colour"""
     
     import sys # import the sys module
@@ -72,48 +98,26 @@ def rainbow(msg, colours=["\033[96m","\033[95m","\033[94m","\033[93m","\033[92m"
     sys.stdout.write(toPrint+end)
 
 
-def colouredPrint(msg, colour="reset", end="\033[0m\n"):
+def colouredPrint(msg, colour="reset", foreOrBack="fore", end="\033[0m\n"):
     """print coloured text. Onced the function has executed the
     colour will be reset back to it's default colour"""
-
-    if(colour == "turquoise"):
-        printColour = "\033[96m"
-
-    elif(colour == "purple"):
-        printColour = "\033[95m"
-
-    elif(colour == "blue"):
-        printColour = "\033[94m"
-
-    elif(colour == "green"):
-        printColour = "\033[92m"
-            
-    elif(colour == "yellow"):
-        printColour = "\033[93m"
-            
-    elif(colour == "red"):
-        printColour = "\033[91m"
-            
-    elif(colour == "gray"):
-        printColour = "\033[90m"
-            
-    elif(colour == "reset"):
-        printColour = "\033[0m"
-        
-    else:
-        printColour = ""
+    
+    colours = {"fore":{"black":"\033[30m", "red":"\033[31m", "green":"\033[32m", "yellow":"\033[33m",
+    "blue":"\033[34m", "magenta":"\033[35m", "cyan":"\033[36m", "white":"\033[37m", "reset":"\033[0m"},
+    "back":{"black":"\033[40m", "red":"\033[41m", "green":"\033[42m", "yellow":"\033[43m",
+    "blue":"\033[44m", "magenta":"\033[45m", "cyan":"\033[46m", "white":"\033[47m", "reset":"\033[0m"}}
         
     import sys # import the sys module
         
     # print the coloured message and then resets the colour
-    sys.stdout.write(printColour + msg + end)
+    sys.stdout.write(colours[foreOrBack][colour] + msg + end)
 
 
 if __name__ == "__main__": # executed if the file is run directly
 	
 	# tells the user about Colour Text
-    print("\033[92mThis file is the \033[91mColoured Text\033[94m module/libray. It is not ment to")
-    print("be executed directly but rather imported and the class within used")
-    print("to create coloured text in \022[90mterminal applications. For more infomation")
+    print("\033[34mThis file is the \033[32;1mColoured Text\033[34;0m module/libray. It is not ment to")
+    print("be executed directly but rather imported and the classes and functions within used")
+    print("to create coloured text in a \033[35mterminal\033[0m applications. For more infomation")
     print("please read the README.md file, go to http://www.github.com/icedvariables/coloured_text")
     print("or go the python package index page https://pypi.python.org/pypi/Coloured_Text")
